#
# spec file for package perl-Event-RPC
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Event-RPC
Version:        1.10
Release:        4.3
%define cpan_name Event-RPC
Summary:        Event based transparent Client/Server RPC framework
License:        GPL-1.0-or-later OR Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Event-RPC/
Source0:        https://cpan.metacpan.org/authors/id/J/JR/JRED/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(AnyEvent)
BuildRequires:  perl(Event)
BuildRequires:  perl(Glib)
BuildRequires:  perl(IO::Socket::SSL)
BuildRequires:  perl(JSON::XS) >= 3
BuildRequires:  perl(Net::SSLeay)
BuildRequires:  perl(Sereal) >= 3
Requires:       perl(AnyEvent)
Requires:       perl(Event)
Requires:       perl(Glib)
Requires:       perl(IO::Socket::SSL)
Requires:       perl(JSON::XS) >= 3
Requires:       perl(Net::SSLeay)
Requires:       perl(Sereal) >= 3
%{perl_requires}

%description
Event::RPC consists of a server and a client library. The server exports a
list of classes and methods, which are allowed to be called over the
network. More specific it acts as a proxy for objects created on the server
side (on demand of the connected clients) which handles client side methods
calls with transport of method arguments and return values.

The object proxy handles refcounting and destruction of objects created by
clients properly. Objects as method parameters and return values are
handled as well (although with some limitations, see below).

For the client the whole thing is totally transparent - once connected to
the server it doesn't know whether it calls methods on local or remote
objects.

Also the methods on the server newer know whether they are called locally
or from a connected client. Your application logic is not affected by
Event::RPC at all, at least if it has a rudimentary clean OO design.

For details on implementing servers and clients please refer to the man
pages of Event::RPC::Server and Event::RPC::Client.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes examples README

%changelog
* Fri Jun 29 2018 coolo@suse.com
- updated to 1.10
  see /usr/share/doc/packages/perl-Event-RPC/Changes
  1.10 Wed Jun 27, 2018, joern
    Bugfixes:
  - Test suite failed on newer Perl versions which
    do not have . in @INC anymore.
* Tue Jun 26 2018 coolo@suse.com
- updated to 1.09
  see /usr/share/doc/packages/perl-Event-RPC/Changes
  1.09 Mon Jun 25, 2018, joern
    Features:
  - Event::RPC::Server->prepare() to support having
    control over the Event loop yourself.
    Bugfixes:
  - SSL tests failed due to expired CA certificate.
    Just created new certificates with 30 year
    expiration and put a gen.sh script inside to
    easily generate new certificates after that
    period ;)
  - Removed unused code. Thanks for the hint to
    ppisar AT redhat.com.
* Fri Jun 24 2016 coolo@suse.com
- updated to 1.08
  see /usr/share/doc/packages/perl-Event-RPC/Changes
  1.08 Sun Sep 26, 2015, joern
    Notes:
  - Just a stable release without changes. I thought
    CPAN testers would pick up developer releases
    too, but was wrong ;)
  1.08_01 Sat Sep 26, 2015, joern
    Features:
  - Support for multiple serialisers: Sereal, CBOR::XS,
    JSON::XS and Storable. That's because Storable is
    known to be insecure, so this module should not
    rely on it.
    Great care has been taken to make these changes
    up- and downwards compatible, so old clients still
    can connect to new servers and vice versa.
    Check documentation chapters MESSAGE FORMAT OPTIONS
    in Event::RPC, Event::RPC::Server and Event::RPC::Client
    manpages for details.
    Thanks to mala <mala AT ma.la> for his hint about the
    security issues of Storable. You find more details in
    this article:
    http://www.masteringperl.org/2012/12/the-storable-security-problem/
    Bugfixes:
  - Proper handling of exceptions which occur at the
    server before a remote method is really executed,
    e.g. when lookup of the class failed due to
    incorrect @INC path.
  - Fixed encoding of source files and corrected
    the year of all Copyright notices.
* Tue Sep 22 2015 coolo@suse.com
- updated to 1.07
  see /usr/share/doc/packages/perl-Event-RPC/Changes
  1.07 Mon Sep 21, 2015, joern
    Features:
  - New method return type '_singleton'. Objects
    created this way are never destroyed on the
    server.
* Sun Sep 20 2015 coolo@suse.com
- updated to 1.06
  see /usr/share/doc/packages/perl-Event-RPC/Changes
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.05
  see /usr/share/doc/packages/perl-Event-RPC/Changes
* Sat Jul 27 2013 coolo@suse.com
- updated to 1.03
    Features:
  - Added options 'ssl_ca_file and 'ssl_ca_path' options
    to Event::RPC::Client, which enable SSL peer verifcation
    on the client. Thanks for the report about a security
    warning of IO::Socket::SSL to Moritz Bunkus.
    Features:
  - Added AnyEvent mainloop implementation.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Aug 22 2010 pascal.bleser@opensuse.org
- initial package (1.01)
